=======
History
=======

1.1.0 (2020-07-16)
------------------

* added a `PylobidPlace` class


1.1.0 (2020-07-16)
------------------

* added a `PylobidPlace` class
* added `same_as` and `pref_name` properties to `PyLobidPerson` and `PyLobidPlace` classes


1.0.0 (2020-07-07)
------------------

* Renamed `PyLobidEntity` to `PyLobidPerson`
* introduced `fetch_related` property
* added Usage-Information to the docs

0.2.2 (2020-06-30)
------------------

* Some useful methods added.

0.2.1 (2020-06-23)
------------------

* Some useful methods added.

0.1.0 (2020-06-21)
------------------

* First release on PyPI.
